@@ -14,15 +14,18 @@ class Executor(object):
         self.rout = rout
         self.variable_list = list()
         self.dfx_folder = os.path.join(os.path.dirname(__file__), "..", "configuration")
+        self.pass_count = 0
+        self.fail_count = 0
 
-    def execute(self, dfx_file):
+    def execute(self, dfx_file, log_folder=None):
         full_path = self.get_full_path(dfx_file)
         if full_path is not None:
-            self.log_dump = Dump()
+            self.log_dump = Dump(log_folder)
             parse_dict = self.parser.run(full_path)
             self.print_coms(parse_dict["com"])
             self.read_and_write_reg(parse_dict["var"])
             self.check_expected(parse_dict["exp"])
+        return self.log_dump.get_result_path(), self.pass_count, self.fail_count
 
     def print_coms(self, coms):
         self.log_dump.log("[COM]\n")
@@ -53,8 +56,10 @@ class Executor(object):
             if expression_string is not None:
                 result, convert_exp = self.calc_expression(expression_string)
                 if result:
+                    self.pass_count += self.pass_count
                     self.log_dump.log("Pass   {}   {} => {}\n".format(expression_info, expression_string, convert_exp))
                 else:
+                    self.fail_count += self.fail_count
                     self.log_dump.log("Fail   {}   {} => {}\n".format(expression_info, expression_string, convert_exp))
 
     def calc_expression(self, expression):
